@@ -55,7 +55,6 @@ public:
     ~PowerDevilUPowerBackend() override;
 
     void init() override;
-    static bool isAvailable();
 
     int brightness(BrightnessControlType type = Screen) const override;
     int brightnessMax(BrightnessControlType type = Screen) const override;
@@ -93,11 +92,11 @@ private:
 
     // upower devices
     QMap<QString, OrgFreedesktopUPowerDeviceInterface *> m_devices;
-    OrgFreedesktopUPowerDeviceInterface *m_displayDevice;
+    OrgFreedesktopUPowerDeviceInterface *m_displayDevice = nullptr;
 
     // brightness
     QMap<BrightnessControlType, int> m_cachedBrightnessMap;
-    DDCutilBrightness *m_ddcBrightnessControl;
+    DDCutilBrightness *m_ddcBrightnessControl = nullptr;
 
     OrgFreedesktopUPowerInterface *m_upowerInterface;
     OrgFreedesktopUPowerKbdBacklightInterface *m_kbdBacklight;
